How To Contribute
=================

Installation
------------

* ``git clone <repository-url>`` this repository
* ``cd ratelimit``
* ``pip install -r requirements.txt``

Linting
-------

* ``pylint ratelimit``
* ``pylint tests``

Running tests
-------------

* ``py.test`` – Runs the pytest test suite
